.. ActingWeb documentation master file, created by
   sphinx-quickstart on Mon Nov 19 20:12:20 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

actingweb - an ActingWeb Python Library
=============================================
This is a python library implementing the REST-based `ActingWeb <http://actingweb.org>`_
distributed micro-services model. It serves as the reference implementation for the ActingWeb REST
protocol specification for how such micro-services interact. In order to follow the specification, an
application needs to implement a set of API endpoints. These can be implemented using any REST framework
(or just plain http requests). See `ActingWeb <http://actingweb.org>`_ for example/boilerplate project(s).

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   LICENSE
   README
   docs/getting-started
   docs/actingweb-spec

   docs/actingweb
   CHANGELOG

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
